@@ -6,7 +6,7 @@ use Mojo::Util qw(dumper);
 use DBI;
 use Carp qw(croak);
 
-our $VERSION  = '0.16';
+our $VERSION  = '0.17';
 
 use MojoX::Mysql::DB;
 use MojoX::Mysql::Result;
@@ -268,6 +268,14 @@ Return L<Mojo::Collection> object.
 
     $mysql->util->quote("test'test");
 
+=head2 quote_in
+
+    $mysql->util->quote_in("test'test");
+
+    # or
+
+    $mysql->util->quote_in(['test','test']);
+
 =head2 id
 
     $mysql->util->id;
