@@ -15,6 +15,16 @@ sub quote {
 	}
 }
 
+sub quote_in {
+	my ($self,$obj,$default) = @_;
+	if(ref $obj eq 'ARRAY'){
+	    return join(",",map($self->quote($_,$default),@{$obj}));
+	}
+	else{
+	    return $self->quote($obj,$default);
+	}
+}
+
 sub id {
 	my ($self) = @_;
 	my @keys = sort {$a <=> $b} grep($_ ne '_default',keys %{$self->{'config'}});
